@@ -111,3 +111,37 @@ test_that("ran_neg_binom", {
   expect_identical(ran_neg_binom(2, c(0.1,100), theta = 1), c(0L, 117L))
   expect_identical(ran_neg_binom(1, c(0.1,100), theta = 1), 0L)
 })
+
+test_that("ran_gamma_pois_zi", {
+  expect_error(ran_gamma_pois_zi(NA_integer_))
+  expect_error(ran_gamma_pois_zi(integer(0)))
+  expect_identical(ran_gamma_pois_zi(0L), integer(0))
+  set.seed(101)
+  expect_identical(ran_gamma_pois_zi(), 1L)
+  expect_identical(ran_gamma_pois_zi(2), c(0L, 2L))
+  expect_identical(ran_gamma_pois_zi(2, 10), c(14L, 7L))
+  expect_identical(ran_gamma_pois_zi(2, c(0.1,100)), c(0L, 108L))
+  expect_identical(ran_gamma_pois_zi(1, c(0.1,100)), 0L)
+  set.seed(101)
+  expect_identical(ran_gamma_pois_zi(prob = 0.5), 0L)
+  expect_identical(ran_gamma_pois_zi(2, prob = 0.5), c(1L, 1L))
+  expect_identical(ran_gamma_pois_zi(2, 10, prob = 0.5), c(7L, 0L))
+  expect_identical(ran_gamma_pois_zi(2, c(0.1,100), prob = 0.5), c(0L, 100L))
+  expect_identical(ran_gamma_pois_zi(1, c(0.1,100), prob = 0.5), 0L)
+  set.seed(101)
+  expect_identical(ran_gamma_pois_zi(theta = 10), 0L)
+  expect_identical(ran_gamma_pois_zi(2, theta = 10), c(1L, 2L))
+  expect_identical(ran_gamma_pois_zi(2, 10, theta = 10), c(0L, 0L))
+  expect_identical(ran_gamma_pois_zi(2, 10, theta = 10), c(7L, 13L))
+  expect_identical(ran_gamma_pois_zi(2, c(0.1,100), theta = 1), c(0L, 12L))
+  expect_identical(ran_gamma_pois_zi(2, c(0.1,100), theta = 1), c(0L, 117L))
+  expect_identical(ran_gamma_pois_zi(1, c(0.1,100), theta = 1), 0L)
+  set.seed(101)
+  expect_identical(ran_gamma_pois_zi(theta = 10, prob = 0.5), 0L)
+  expect_identical(ran_gamma_pois_zi(2, theta = 10, prob = 0.5), c(0L, 0L))
+  expect_identical(ran_gamma_pois_zi(2, 10, theta = 10, prob = 0.5), c(9L, 0L))
+  expect_identical(ran_gamma_pois_zi(2, 10, theta = 10, prob = 0.5), c(0L, 0L))
+  expect_identical(ran_gamma_pois_zi(2, c(0.1,100), theta = 1, prob = 0.5), c(0L, 0L))
+  expect_identical(ran_gamma_pois_zi(2, c(0.1,100), theta = 1, prob = 0.5), c(0L, 0L))
+  expect_identical(ran_gamma_pois_zi(1, c(0.1,100), theta = 1, prob = 0.5), 0L)
+})
