@@ -4,4 +4,6 @@ test_that("upper", {
   expect_equal(upper(1), 1)
   expect_equal(upper(c(1, 1)), 1)
   expect_equal(upper(0:100), 97.5)
+  expect_equal(upper(c(0:100, NA)), NA_real_)
+  expect_equal(upper(c(0:100, NA), na_rm = TRUE), 97.5)
 })
